#
# spec file for package tre
#
# Copyright (c) 2022 SUSE LLC
# Copyright (c) 2024 Andreas Stieger <Andreas.Stieger@gmx.de>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define sover 5
Name:           tre
Version:        0.9.0
Release:        1.2
Summary:        POSIX-compatible regexp library with approximate matching
License:        BSD-3-Clause
Group:          Development/Libraries/C and C++
URL:            https://laurikari.net/tre/
Source0:        https://github.com/laurikari/tre/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  glibc-locale
%lang_package -n libtre%{sover}

%description
TRE is a POSIX-compatible regexp matching library with approximate
(fuzzy) matching.

%package -n libtre%{sover}
Summary:        POSIX-compatible regexp library with approximate matching
Group:          System/Libraries

%description -n libtre%{sover}
TRE is a POSIX-compatible regexp matching library with approximate
(fuzzy) matching. TRE's algorithm has linear worst-case time in the
length of the text being searched, and quadratic worst-case time in
the length of the used regular expression.

%package devel
Summary:        Header files for the TRE regex library
Group:          Development/Libraries/C and C++
Requires:       libtre%{sover} = %{version}

%description devel
TRE is a POSIX-compatible regexp matching library with approximate
This package contains the headers.

%package -n agrep
Summary:        Another grep with approximate matching and block search
Group:          Productivity/Text/Utilities

%description -n agrep
agrep is a grep utility which has the ability to search for
approximate patterns as well as block oriented search.

%prep
%autosetup -p1

%build
%configure --disable-static --enable-shared
%make_build

%install
%make_install
find %{buildroot} -type f -name "*.la" -delete -print
%find_lang %{name}

%check
%make_build check

%ldconfig_scriptlets -n libtre%{sover}

%files -n libtre%{sover}
%license LICENSE
%{_libdir}/libtre.so.*

%files devel
%license LICENSE
%doc doc/default.css doc/tre-api.html doc/tre-syntax.html
%{_includedir}/*
%{_libdir}/libtre.so
%{_libdir}/pkgconfig/*

%files -n agrep
%license LICENSE
%{_bindir}/agrep
%{_mandir}/man1/agrep.1%{?ext_man}

%files -n libtre%{sover}-lang -f %{name}.lang
%license LICENSE

%changelog
* Fri Nov 22 2024 Andreas Stieger <andreas.stieger@gmx.de>
- update to 0.9.0:
  * Modify the bound parser to allow the minimum and maximum count
    to be omitted, defaulting to zero and infinity, respectively.
  * Add API variants for operating on raw byte vectors:
    tre_regnexecb, tre_regexecb, tre_regncompb, tre_regaexecb,
    tre_regcompb
  * Bug fixes
- drop unneeded patches or patches included upstream:
  * 0001-Remove-broken-agrep-test-entry.patch
  * CVE-2016-8859.patch
  * tre-chicken.patch
  * tre.diff
- drop legacy obsoletes/provides
* Tue Oct 11 2022 Fabian Vogt <fvogt@suse.com>
- Add patch to fix testsuite with bash >= 5.2:
  * 0001-Remove-broken-agrep-test-entry.patch
* Thu Jan 27 2022 Dirk Müller <dmueller@suse.com>
- require glibc-locale
* Thu Jan 30 2020 Ondřej Súkup <mimi.vx@gmail.com>
- remove python2 bindings
* Tue Jan 16 2018 kbabioch@suse.com
- CVE-2016-8859.patch: Fix multiple integer overflows which allowed
  attackers to cause memory corruption via a large number of (1) states or
  (2) tags, which triggered an out-of-bounds write (bnc#1005483)
* Thu Apr 24 2014 pgajdos@suse.com
- remove redundant setting of C(XX)FLAGS
- package translations in tre-lang
* Tue Apr  8 2014 bjones@ece.msstate.edu
- Added make check tests
- Added python-tre wrapper
- Used updated source from https://github.com/laurikari/tre/
- Added chicken.patch to correct Python build failures
* Tue May  8 2012 cfarrell@suse.com
- license update: BSD-3-Clause
  Package is predominantly BSD-3-Clause licensed. This spec file license
  update makes the openSUSE package license substantially similar to the
  Fedora package license"
* Sun Jan 29 2012 jengelh@medozas.de
- Remove redundant tags/sections per specfile guideline suggestions
- Parallel building using %%_smp_mflags
- Enable pkgconfig provides
* Thu Dec 10 2009 pgajdos@suse.cz
- updated to 0.8.0:
  - Added tre_ prefix to all functions exported from libtre.  This
    changes the binary interface (ABI).  The old source interface
    (API) is still available in <tre/regex.h>.  New programs should
    use <tre/tre.h>.
  - Visual C++ 6 project files replaced with Visual Studio 2008 files.
  - Bug fixes.
- package renamed to tre, splitted out subpackage libtre5
* Thu Jun 18 2009 pgajdos@suse.cz
- updated to 0.7.6 (see NEWS)
* Thu Jan 24 2008 coolo@suse.de
- fix build
* Sun Feb 25 2007 dmueller@suse.de
- Initial package (0.7.5)
